@@ -194,3 +194,8 @@ def test_table_cells():
     cell2 = CustomCell((0, 0), 1, 2, visible_edges=None)
     table[2, 1] = cell2
     assert table[2, 1] is cell2
+
+    # make sure gettitem support has not broken
+    # properties and setp
+    table.properties()
+    plt.setp(table)
